@@ -30,6 +30,7 @@ from astropy.time import Time
 from astroquery.sdss import SDSS
 
 from fink_utils.photometry.conversion import dc_mag
+from fink_utils.xmatch.simbad import return_list_of_eg_host
 
 from fink_filters.tester import spark_unit_tests
 
@@ -85,7 +86,7 @@ def perform_classification(
 
     high_drb = drb.astype(float) > 0.9
     high_classtar = classtar.astype(float) > 0.4
-    new_detection = jd.astype(float) - jdstarthist.astype(float) < 14
+    new_detection = jd.astype(float) - jdstarthist.astype(float) < 5
     small_detection_history = ndethist.astype(float) < 20
     appeared = isdiffpos.astype(str) == 't'
     far_from_mpc = (ssdistnr.astype(float) > 10) | (ssdistnr.astype(float) < 0)
@@ -95,27 +96,7 @@ def perform_classification(
 
     awaw_from_galactic_plane = np.abs(b) > 10
 
-    list_simbad_galaxies = [
-        "galaxy",
-        "Galaxy",
-        "EmG",
-        "Seyfert",
-        "Seyfert_1",
-        "Seyfert_2",
-        "BlueCompG",
-        "StarburstG",
-        "LSB_G",
-        "HII_G",
-        "High_z_G",
-        "GinPair",
-        "GinGroup",
-        "BClG",
-        "GinCl",
-        "PartofG",
-    ]
-
-    keep_cds = \
-        ["Unknown", "Transient", "Fail"] + list_simbad_galaxies
+    keep_cds = return_list_of_eg_host()
 
     f_kn = high_drb & high_classtar & new_detection & small_detection_history
     f_kn = f_kn & cdsxmatch.isin(keep_cds) & appeared & far_from_mpc
@@ -300,7 +281,7 @@ def rate_based_kn_candidates(
     Examples
     ----------
     >>> from fink_utils.spark.utils import concat_col
-    >>> from fink_filters.utilities import apply_user_defined_filter
+    >>> from fink_utils.spark.utils import apply_user_defined_filter
     >>> df = spark.read.format('parquet').load('datatest')
 
     >>> to_expand = ['jd', 'fid', 'magpsf', 'sigmapsf', 'magnr', 'sigmagnr', 'magzpsci', 'isdiffpos']
