@@ -39,7 +39,7 @@ def simbad_candidates_(cdsxmatch) -> pd.Series:
     >>> classification = simbad_candidates_(pdf['cdsxmatch'])
     >>> nalerts = len(pdf[classification]['objectId'])
     >>> print(nalerts)
-    293
+    290
 
     >>> pdf[classification].groupby('cdsxmatch').count().sort_values('objectId', ascending=False)['objectId'].head()
     cdsxmatch
@@ -47,10 +47,18 @@ def simbad_candidates_(cdsxmatch) -> pd.Series:
     Blue           7
     HotSubdwarf    6
     TTau*          5
-    CataclyV*      5
+    Symbiotic*     5
     Name: objectId, dtype: int64
     """
-    f_simbad = ~cdsxmatch.isin(['Unknown', 'Transient', 'Fail'])
+    f_simbad = ~cdsxmatch.isin(['Unknown', 'Transient', 'Fail', 'Fail 504'])
+
+    # mask all kind of failures
+    mask = cdsxmatch.apply(lambda x: x.startswith('Fail'))
+    f_simbad[mask] = False
+
+    # Remove static objects -- https://github.com/astrolabsoftware/fink-filters/issues/120
+    mask_gal = cdsxmatch.apply(lambda x: x.startswith('Galaxy'))
+    f_simbad[mask_gal] = False
 
     return f_simbad
 
@@ -71,12 +79,12 @@ def simbad_candidates(cdsxmatch) -> pd.Series:
 
     Examples
     ----------
-    >>> from fink_filters.utilities import apply_user_defined_filter
+    >>> from fink_utils.spark.utils import apply_user_defined_filter
     >>> df = spark.read.format('parquet').load('datatest')
     >>> f = 'fink_filters.filter_simbad_candidates.filter.simbad_candidates'
     >>> df = apply_user_defined_filter(df, f)
     >>> print(df.count())
-    293
+    290
 
     """
     f_simbad = simbad_candidates_(cdsxmatch)
